# 2021-04-18 Authorizer

Initial version of the Authorizer contract, which powers Balancer governance.

This contract is expected to be eventually replaced by one with a) native support for timelocks and b) more granular roles, that is, being able to grant powers over a subset of related contracts. These development efforts are tracked [here](https://github.com/balancer-labs/balancer-v2-monorepo/milestone/4).

## Useful Files

- [Ethereum mainnet address](./output/mainnet.json)
- [Polygon mainnet address](./output/polygon.json)
- [Arbitrum mainnet address](./output/arbitrum.json)
- [`Authorizer` ABI](./abi/Authorizer.json)
